@@ -29,9 +29,8 @@ pub enum ControlPlane {
     Kubeadm(KubeadmControlPlane),
 }
 
-#[derive(Debug)]
-pub enum ControlPlaneConfigTemplate {
-    Kubeadm(KubeadmConfigTemplate),
+pub trait ControlPlaneConfigTemplate {
+    fn object_ref(&self) -> corev1::ObjectReference;
 }
 
 #[derive(Debug)]
@@ -39,7 +38,6 @@ pub enum Infrastructure {
     Aws(AWSCluster),
 }
 
-#[derive(Debug)]
-pub enum MachineTemplate {
-    Aws(AWSMachineTemplate),
+pub trait MachineTemplate {
+    fn object_ref(&self) -> corev1::ObjectReference;
 }
