@@ -7,7 +7,10 @@ impl MachineDeployment {
     }
 
     #[must_use]
-    pub fn machine_template(mut self, machine_template: &MachineTemplate) -> Self {
+    pub fn machine_template<T>(mut self, machine_template: &T) -> Self
+    where
+        T: MachineTemplate,
+    {
         let infrastructure_ref = machine_template.object_ref();
         let mut spec = self.spec.template.spec.take().unwrap_or_default();
         spec.infrastructure_ref = infrastructure_ref;
@@ -24,11 +27,16 @@ impl MachineDeployment {
     }
 
     #[must_use]
-    pub fn bootstrap_config_ref(mut self, template: &ControlPlaneConfigTemplate) -> Self {
-        let config_ref = template.object_ref();
-        let mut spec = self.spec.template.spec.take().unwrap_or_default();
-        spec.bootstrap.config_ref = Some(config_ref);
-        self.spec.template.spec = Some(spec);
+    pub fn bootstrap<T>(mut self, template: &T) -> Self
+    where
+        T: ControlPlaneConfigTemplate,
+    {
+        self.spec
+            .template
+            .spec
+            .get_or_insert_with(Default::default)
+            .bootstrap
+            .config_ref = Some(template.object_ref());
         self
     }
 }
